@@ -16,6 +16,11 @@
 # limitations under the License.
 # ------------------------------------------------------------------------
 
-# Versioning convention
-# https://www.python.org/dev/peps/pep-0440/
-__version__ = "0.5.1"
+from __future__ import annotations
+
+try:
+    from importlib import metadata
+except ImportError:
+    import importlib_metadata as metadata
+
+__version__ = metadata.version("histolab")
