@@ -583,25 +583,32 @@ def rgb_to_lab(
     np.ndarray
         Array representation of the image in LAB space
 
-    Raises
-    ------
-    Exception
-        If the image mode is not RGB
     """
-    if img.mode != "RGB":
-        raise Exception("Input image must be RGB")
+    if img.mode == "L":
+        raise ValueError("Input image must be RGB or RGBA")
+
+    if img.mode == "RGBA":
+        red, green, blue, _ = img.split()
+        img = PIL.Image.merge("RGB", (red, green, blue))
+
+        warn(
+            "Input image must be RGB. "
+            "NOTE: the image will be converted to RGB before OD conversion."
+        )
     img_arr = np.array(img)
     lab_arr = sk_color.rgb2lab(img_arr, illuminant=illuminant, observer=observer)
     return lab_arr
 
 
-def rgb_to_od(img: PIL.Image.Image) -> np.ndarray:
+def rgb_to_od(img: PIL.Image.Image, background_intensity: int = 240) -> np.ndarray:
     """Convert from RGB to optical density (OD_RGB) space.
 
     Parameters
     ----------
     img : PIL.Image.Image
         Input image
+    background_intensity : int, optional
+        Background transmitted light intensity. Default is 240.
 
     Returns
     -------
@@ -619,7 +626,7 @@ def rgb_to_od(img: PIL.Image.Image) -> np.ndarray:
 
     img_arr = np.array(img)
 
-    od_arr = -np.log((img_arr.astype(float) + 1) / 240)
+    od_arr = -np.log((img_arr.astype(np.float) + 1) / background_intensity)
     return od_arr
 
 
