@@ -36,7 +36,7 @@ from .exceptions import (
 from .filters.compositions import FiltersComposition
 from .tile import Tile
 from .types import CoordinatePair
-from .util import lazyproperty
+from .util import lazyproperty, refine_thumbnail_size_preserving_aspect_ratio
 
 if TYPE_CHECKING:
     from .masks import BinaryMask
@@ -51,8 +51,8 @@ except (ModuleNotFoundError, ImportError):  # pragma: no cover
     LARGEIMAGE_IS_INSTALLED = False
 
 IMG_EXT = "png"
-IMG_UPSAMPLE_MODE = PIL.Image.BICUBIC
-IMG_DOWNSAMPLE_MODE = PIL.Image.LANCZOS
+IMG_UPSAMPLE_MODE = PIL.Image.Resampling.BICUBIC
+IMG_DOWNSAMPLE_MODE = PIL.Image.Resampling.LANCZOS
 TILE_SIZE_PIXEL_TOLERANCE = 5
 
 
@@ -390,7 +390,7 @@ class Slide:
         img = self.scaled_image(scale_factor)
         mask = binary_mask(self)
         resized_mask = np.array(
-            PIL.Image.fromarray(mask).resize(img.size, PIL.Image.ANTIALIAS)
+            PIL.Image.fromarray(mask).resize(img.size, PIL.Image.Resampling.LANCZOS)
         )
 
         if tissue_mask:
@@ -497,10 +497,14 @@ class Slide:
             The slide thumbnail.
         """
         if self._use_largeimage:
+            # large-image does not preserve the aspect ratio for the thumbnail.
+            width, height = refine_thumbnail_size_preserving_aspect_ratio(
+                self._thumbnail_size, self.dimensions
+            )
             thumb_bytes, _ = self._tile_source.getThumbnail(
                 encoding="PNG",
-                width=self._thumbnail_size[0],
-                height=self._thumbnail_size[1],
+                width=width,
+                height=height,
             )
             thumbnail = self._bytes2pil(thumb_bytes).convert("RGB")
             return thumbnail
@@ -677,14 +681,13 @@ class Slide:
 
         .. math::
 
-            \big(\frac{v}{10^{w-2}},\frac{v}{10^{n-2}}\big)
+            \big(\frac{v}{10^{w-2}},\frac{m}{10^{n-2}}\big)
 
         Returns
         -------
         Tuple[int, int]
             Thumbnail size
         """
-
         return tuple(
             [
                 int(s / np.power(10, math.ceil(math.log10(s)) - 3))
